@@ -12,6 +12,7 @@ from src.app import App
 from src.utils import my_json
 from sys import exit
 from lxml import etree
+from .__version__ import __version__
 this_dir, this_filename = os.path.split(__file__)
 
 
@@ -64,16 +65,16 @@ def main(argv=None):
     parse_xml(inputfile, name, customer, outfolder, git_repo)
 
 def show_version():
-    import re
-    VERSIONFILE="src/__version__.py"
-    verstrline = open(VERSIONFILE, "rt").read()
-    VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
-    mo = re.search(VSRE, verstrline, re.M)
-    if mo:
-        verstr = mo.group(1)
-    else:
-        raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))
-    print("version {}".format(verstr))
+    # import re
+    # VERSIONFILE="__version__.py"
+    # verstrline = open(VERSIONFILE, "rt").read()
+    # VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
+    # mo = re.search(VSRE, verstrline, re.M)
+    # if mo:
+    #     verstr = mo.group(1)
+    # else:
+    #     raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))
+    print("version {}".format(__version__))
 
 
 def usage():
