@@ -9,6 +9,7 @@ from src.web.webpagedef import WebPageDef
 from src.web.portal import Portal
 from src.seedrecord import SeedRecord
 from src.app_event import Event
+from src.app_custom_method import CustomMethod
 
 this_dir, this_filename = os.path.split(__file__)
 
@@ -33,7 +34,7 @@ class App(object):
     is_logo_hidden = ""
 
     def __init__(self, app_name, id, version, packed_id, displayname, description, properties, objects, files,
-                 menus, webpages, portals, seeds, dependents, batchs, outfolder, git_repo, creation_date):
+                 menus, webpages, portals, seeds, dependents, batchs, outfolder, git_repo, creation_date, custom_methods):
         self.id = id
         self.app_name = app_name
         self.version = version
@@ -74,6 +75,7 @@ class App(object):
         self.batchs = batchs
         self.git_repo = git_repo
         self.creation_date = creation_date
+        self.custom_methods = custom_methods
         # delete all files and folder to make git tracking easyest
         for x in ["hosted_files", "menus", "objects", "pages", "portals",
                   "seeds"]:
@@ -87,7 +89,7 @@ class App(object):
             os.makedirs(self.app_directory.encode('utf-8'))
 
     def check_git_exists(self):
-        if not os.path.exists(self.app_directory + "/.git".encode('utf-8')):
+        if not os.path.exists(self.app_directory + "/.git"):
             # os.makedirs(self.app_directory)
             self.git_repo_obj = Repo.init(self.app_directory)
             self.git_origin = self.git_repo_obj.create_remote('origin', url=self.git_repo)
@@ -253,6 +255,9 @@ class App(object):
 
         if self.batchs:
             self.create_batchs()
+        
+        if self.custom_methods:
+            self.create_custom_methods()
 
         return self.app_directory
 
@@ -276,6 +281,8 @@ class App(object):
             menu_file.write(new_menu.get_menus(self.menus))
         menu_file.write("```\n")
 
+
+
     def create_hosted_files(self):
         ### HOSTED FILES
         hosted_files_dir = "{}/hosted_files".format(self.app_directory)
@@ -351,6 +358,11 @@ class App(object):
         for batch in self.batchs:
             event = Event(batch, self.app_directory + "/jobs/")
             event.to_file()
+    
+    def create_custom_methods(self):
+        for method in self.custom_methods:
+            event = CustomMethod(method, self.app_directory + "/custom_methods/")
+            event.to_file()
 
 
 class MyProgressPrinter(RemoteProgress):
