@@ -34,8 +34,8 @@ class Event(object):
 
     def to_file(self):
         # properties file
-        if not os.path.exists(self.event_dir):
-            os.makedirs(self.event_dir)
+        if not os.path.exists(self.event_dir.encode('utf-8')):
+            os.makedirs(self.event_dir.encode('utf-8'))
         file = open("{}/PROPERTIES.md".format(self.event_dir), 'w+', encoding='utf-8')
         with file:
             # nom de l'objet
