@@ -24,11 +24,11 @@ class WebPage(object):
         self.page_dir = "{}/{}".format(webpagedef_dir, dirname)
 
     def to_file(self):
-        if not os.path.exists(self.page_dir):
-            os.makedirs(self.page_dir)
+        if not os.path.exists(self.page_dir.encode('utf-8')):
+            os.makedirs(self.page_dir.encode('utf-8'))
         # fichier de propriétés
-        if not os.path.exists(self.page_dir):
-            os.makedirs(self.page_dir)
+        if not os.path.exists(self.page_dir.encode('utf-8')):
+            os.makedirs(self.page_dir.encode('utf-8'))
         file = open("{}/PROPERTIES.md".format(self.page_dir), 'w+', encoding='utf-8')
         with file:
             # nom de l'objet
